<?php
// Include database connection
include 'db_connection.php';

// Query to fetch the total amount from the database
$sql = "SELECT SUM(amount) AS total_amount FROM payments";
$result = $conn->query($sql);

$totalAmount = 0;
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $totalAmount = $row['total_amount'] ? (float)$row['total_amount'] : 0;
}

// Calculate 20% of the total amount
$twentyPercent = $totalAmount * 0.20;

// Calculate the earned amount (80% of total)
$amountEarned = $totalAmount - $twentyPercent;

// Format the amounts for display
$formattedTotal = number_format($totalAmount, 2);
$formattedTwentyPercent = number_format($twentyPercent, 2);
$formattedEarned = number_format($amountEarned, 2);
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Dashboard Header</title>
  <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
  <link rel="stylesheet" href="https://cdn.datatables.net/1.10.24/css/dataTables.bootstrap4.min.css">
  <link rel="stylesheet" href="styles.css">
  
  <style>
    /* Custom styling for header, sidebar, and main content */
    .header {
      background-color: #20C997;
      color: #fff;
      padding: 10px 20px;
      display: flex;
      align-items: center;
      justify-content: space-between;
    }
    .navbar-brand {
      font-size: 1.5em;
      font-weight: bold;
    }
    .toggle-btn {
      font-size: 1.5em;
      color: #fff;
      background: none;
      border: none;
      cursor: pointer;
    }
    .subheader {
      background-color: #f1f1f1;
      padding: 10px 20px;
      display: flex;
      justify-content: space-between;
      align-items: center;
      border-bottom: 1px solid #ddd;
    }
    .breadcrumb-item a {
      color: #007bff;
    }
    .icon-buttons i {
      font-size: 1.2em;
      margin-left: 20px;
      cursor: pointer;
      color: #555;
    }
    .sidebar {
      width: 250px;
      background-color: #403f34;
      color: #fff;
      position: fixed;
      top: 136px;
      left: 0;
      height: calc(100vh - 110px);
      transition: 0.3s;
    }
    .sidebar .nav-link {
      color: #fff;
      padding: 15px 20px;
      display: flex;
      align-items: center;
    }
    .sidebar .nav-link i {
      font-size: 1.2em;
      margin-right: 10px;
    }
    .main-content {
      margin-top: 10px;
      margin-left: 250px;
      padding: 20px;
      transition: 0.3s;
    }

    /* Hide sidebar by default on mobile view */
    @media (max-width: 768px) {
      .sidebar {
        display: none;
        width: 250px;
        position: fixed;
        z-index: 1000;
        left: 0;
      }
      .sidebar.show {
        display: block;
      }
      .main-content {
        margin-left: 0;
      }
      .header, .subheader {
        flex-direction: column;
        align-items: flex-start;
      }
    }
  </style>
</head>
<body>
  
  <!-- Header Section -->
  <header class="header">
    <a class="navbar-brand text-white" href="#">Payments</a>
    <button class="toggle-btn" onclick="toggleSidebar(event)">
      <i class="fas fa-bars"></i>
    </button>
  </header>

  <!-- Subheader Section -->
  <div class="subheader">
    <div class="icon-buttons d-flex align-items-center">
      <i class="fas fa-bell" title="Notifications"></i>
      <div class="dropdown ml-3">
        <i class="fas fa-user-circle dropdown-toggle" id="profileDropdown" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false"></i>
        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="profileDropdown">
          <a class="dropdown-item" href="#"><i class="fas fa-cog mr-2"></i>Settings</a>
          <a class="dropdown-item" href="#"><i class="fas fa-bell mr-2"></i>Notifications</a>
          <a class="dropdown-item" href="#"><i class="fas fa-sign-out-alt mr-2"></i>Logout</a>
        </div>
      </div>
    </div>
  </div>

  <!-- Sidebar Section -->
  <div id="sidebar" class="sidebar">
    <a href="#" class="nav-link">
      <i class="fas fa-tachometer-alt"></i><span>Dashboard</span>
    </a>
    <a href="#" class="nav-link">
      <i class="fas fa-book"></i><span>Website</span>
    </a>
    <a href="#" class="nav-link">
      <i class="fas fa-chart-line"></i><span>Profile</span>
    </a>
    <a href="#" class="nav-link">
      <i class="fas fa-user-check"></i><span>Divert link</span>
    </a>
  </div>

  <!-- Main Content Section -->
  <div class="main-content" id="main-content">
    <!-- Data Table Section -->
    <h4>Websites</h4>
<!-- Main Content -->
<div class="container-fluid p-4">
<!-- Summary Cards -->
<div class="container-fluid p-4">
    <div class="row mb-4">
      <div class="col-md-4">
        <div class="card text-center">
          <div class="card-body">
            <h5 class="card-title">Total Amount</h5>
            <p class="card-text text-primary fs-4"><?php echo $formattedTotal; ?></p>
          </div>
        </div>
      </div>
      <div class="col-md-4">
        <div class="card text-center">
          <div class="card-body">
            <h5 class="card-title">20 Percent</h5>
            <p class="card-text text-danger fs-4"><?php echo $formattedTwentyPercent; ?></p>
          </div>
        </div>
      </div>
      <div class="col-md-4">
        <div class="card text-center">
          <div class="card-body">
            <h5 class="card-title">Amount Earned</h5>
            <p class="card-text text-success fs-4"><?php echo $formattedEarned; ?></p>
          </div>
        </div>
      </div>
    </div>
  </div>
  
    <!-- Table Section -->
    <div class="card">
      <div class="card-header d-flex justify-content-between align-items-center">
        <h5>Websites</h5>
        <button class="btn btn-primary btn-sm">+ Add Website</button>
      </div>
      <div class="card-body table-container">
    <table class="table table-striped sortable">
        <thead>
            <tr>
                <th onclick="sortTable(0)"># <i class="fas fa-sort"></i></th>
                <th onclick="sortTable(1)">Phone Number <i class="fas fa-sort"></i></th>
                <th onclick="sortTable(2)">Link <i class="fas fa-sort"></i></th>
                <th onclick="sortTable(3)">Amount Earned <i class="fas fa-sort"></i></th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php
            // Include your database connection file
            include 'db_connection.php'; // Ensure the correct file path

            // Fetch records from the 'payments' table
            //$sql = "SELECT id, phone_number, link, amount FROM payments";
            $sql = "SELECT id, link, SUM(amount) AS total_amount FROM payments GROUP BY link";
            $result = $conn->query($sql);

            if ($result->num_rows > 0) {
                while ($row = $result->fetch_assoc()) {
                    echo '<tr>';
                    echo '<td>' . $row['id'] . '</td>';
                   // echo '<td>' . htmlspecialchars($row['phone_number']) . '</td>';
                    echo '<td><a href="' . htmlspecialchars($row['link']) . '" target="_blank">' . htmlspecialchars($row['link']) . '</a></td>';
                    echo '<td>' . number_format($row['total_amount'], 2) . '</td>';
                    echo '<td>
                            <button class="btn btn-warning btn-sm">Edit</button>
                            <button class="btn btn-danger btn-sm">Delete</button>
                          </td>';
                    echo '</tr>';
                }
            } else {
                echo '<tr><td colspan="5" class="text-center">No records found.</td></tr>';
            }

            $conn->close(); // Close the database connection
            ?>
        </tbody>
    </table>
</div>

  
  </div>

  <!-- Bootstrap, DataTables JS and dependencies -->
  <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
  <script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.1/dist/umd/popper.min.js"></script>
  <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
  <script src="https://cdn.datatables.net/1.10.24/js/jquery.dataTables.min.js"></script>
  <script src="https://cdn.datatables.net/1.10.24/js/dataTables.bootstrap4.min.js"></script>

  <script>
    $(document).ready(function() {
      $('#pendingLogsTable').DataTable({
        responsive: true,
        searching: true,
        ordering: true,
        paging: true,
        info: true
      });
      
      // Hide sidebar when clicking outside
      document.addEventListener('click', function(event) {
        const sidebar = document.getElementById("sidebar");
        const toggleBtn = document.querySelector(".toggle-btn");

        if (sidebar.classList.contains("show") && !sidebar.contains(event.target) && !toggleBtn.contains(event.target)) {
          sidebar.classList.remove("show");
        }
      });
    });

    function toggleSidebar(event) {
      event.stopPropagation(); // Prevent the event from closing the sidebar immediately after opening
      const sidebar = document.getElementById("sidebar");
      sidebar.classList.toggle("show");
    }
  </script>
  <script>
    function sortTable(column) {
  const table = document.querySelector('.sortable tbody');
  const rows = Array.from(table.rows);
  const isNumeric = !isNaN(rows[0].cells[column].innerText);

  rows.sort((a, b) => {
    const aText = a.cells[column].innerText.trim();
    const bText = b.cells[column].innerText.trim();

    if (isNumeric) {
      return parseFloat(aText) - parseFloat(bText);
    }
    return aText.localeCompare(bText);
  });

  rows.forEach(row => table.appendChild(row));
}

  </script>
</body>
</html>
